Here we look at cljdoc features for APIs
Namespace docstrings can contain markdown.
And should support links repo to articles and inline repo images

Wikilinks work from namespace docstrings:
exercise7cljdoc-exerciser.ns2cljdoc-exerciser.ns2/whateverWikilink syntax [[that does not resolve to any var or ns]] is not converted to a link, this includes any typos like [[cljdoc-exerciser.ns2/whatevs]] [[cljdoc-exorcisor.core]]
With wikilinks and root relative links, we discourage and don't need fully qualified links, but they should work:
Here we look at cljdoc features for APIs Namespace docstrings **can** contain markdown. And should support links repo [to articles](/doc/tests/md-features.md) and inline repo images  Wikilinks work from namespace docstrings: - a var local to this namespace [[exercise7]] - a different namespace [[cljdoc-exerciser.ns2]] - a var in a different namespace [[cljdoc-exerciser.ns2/whatever]] Wikilink syntax [[that does not resolve to any var or ns]] is not converted to a link, this includes any typos like [[cljdoc-exerciser.ns2/whatevs]] [[cljdoc-exorcisor.core]] With wikilinks and root relative links, we discourage and don't need fully qualified links, but they should work: 1. [A fully qualified link to cljdoc-exerciser.core/excercise3](https://cljdoc.org/d/org.cljdoc/cljdoc-exerciser/CURRENT/api/cljdoc-exerciser.core#exercise3) 2. [A fully qualified link to cljdoc-exerciser.core](https://cljdoc.org/d/org.cljdoc/cljdoc-exerciser/CURRENT/api/cljdoc-exerciser.core)
Clojure namespace - test when there are differences between platforms.
Wikilinks test: clj-only cljs-only docs-and-args-differ proto1-same2 proto3-cljs-only proto3-clj-only proto3-same
Clojure namespace - test when there are differences between platforms. Wikilinks test: [[clj-only]] [[cljs-only]] [[docs-and-args-differ]] [[proto1-same2]] [[proto3-cljs-only]] [[proto3-clj-only]] [[proto3-same]]
ClojureScript namespace - test when there are differences between platforms.
Wikilinks test: clj-only cljs-only docs-and-args-differ proto1-same2 proto3-cljs-only proto3-clj-only proto3-same
ClojureScript namespace - test when there are differences between platforms. Wikilinks test: [[clj-only]] [[cljs-only]] [[docs-and-args-differ]] [[proto1-same2]] [[proto3-cljs-only]] [[proto3-clj-only]] [[proto3-same]]
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |